get_software_name — MSUMastro toolbox 0.1 documentation

# get_software_name

`msumastro.header_processing.patchers.` `get_software_name`(header, file_name=None, use_observatory=None)

  Determine the name of the software that created FITIS header

  Parameters: | header : astropy.io.fits Header Header from a FITS extension/hdu file_name : str, optional Name of the file containing this header; used to add information to error/warning messages. use_observatory : msumastro.Feder instance, optional Object that contains names of FITS keywords that might be present and contain name of the software that made this header. The default value is the instance defined at the beginning of this module
  Returns: | msumastro.feder.Software object